AlignContent

Struct AlignContent 

pub struct AlignContent {
    pub keyword: AlignContentKeyword,
    pub safety: AlignmentSafety,
}
Sets the distribution of space between and around content items. For Flexbox it controls alignment in the cross axis. For Grid it controls alignment in the block axis.

MDN

Fields

keyword: AlignContentKeyword

Position keyword.

safety: AlignmentSafety

Overflow-position modifier (safe / unsafe).

Implementations

Source

impl AlignContent

pub const START: Self

Items are packed toward the start of the axis.

pub const END: Self

Items are packed toward the end of the axis.

pub const FLEX_START: Self

Items are packed towards the flex-relative start of the axis.

pub const FLEX_END: Self

Items are packed towards the flex-relative end of the axis.

pub const CENTER: Self

Items are centered around the middle of the axis.

pub const STRETCH: Self

Items are stretched to fill the container.

pub const SPACE_BETWEEN: Self

The first and last items are aligned flush with the edges of the container.

pub const SPACE_EVENLY: Self

The gap between the first and last items equals the gap between items.

pub const SPACE_AROUND: Self

The gap between the first and last items is half the gap between items.

pub const SAFE_START: Self

Like AlignContent::START, but falls back to AlignContent::START when the content overflows the alignment container, to avoid data loss.

pub const SAFE_END: Self

Like AlignContent::END, but falls back to AlignContent::START when the content overflows the alignment container, to avoid data loss.

pub const SAFE_FLEX_START: Self

Like AlignContent::FLEX_START, but falls back to AlignContent::START when the content overflows the alignment container, to avoid data loss.

pub const SAFE_FLEX_END: Self

Like AlignContent::FLEX_END, but falls back to AlignContent::START when the content overflows the alignment container, to avoid data loss.

pub const SAFE_CENTER: Self

Like AlignContent::CENTER, but falls back to AlignContent::START when the content overflows the alignment container, to avoid data loss.

pub const fn is_safe(self) -> bool

Returns true iff this carries the safe overflow-position modifier.

pub const fn keyword(self) -> AlignContentKeyword

Returns the underlying position keyword, discarding the safety modifier.