AlignSelf

Type Alias AlignSelf 

pub type AlignSelf = AlignItems;
Controls alignment of an individual node.

Overrides the parent Node’s AlignItems property. For Flexbox it controls alignment in the cross axis. For Grid it controls alignment in the block axis.

MDN

Aliased Type

pub struct AlignSelf {
    pub keyword: AlignItemsKeyword,
    pub safety: AlignmentSafety,
}

Fields

keyword: AlignItemsKeyword

Position keyword.

safety: AlignmentSafety

Overflow-position modifier (safe / unsafe).