JustifyItems

Type Alias JustifyItems 

pub type JustifyItems = AlignItems;
Used to control how child nodes are aligned. Does not apply to Flexbox, and will be ignored if specified on a flex container. For Grid it controls alignment in the inline axis.

MDN

Aliased Type

pub struct JustifyItems {
    pub keyword: AlignItemsKeyword,
    pub safety: AlignmentSafety,
}

Fields

keyword: AlignItemsKeyword

Position keyword.

safety: AlignmentSafety

Overflow-position modifier (safe / unsafe).