#[repr(u8)]pub enum AlignItemsKeyword {
Start = 0,
End = 1,
FlexStart = 2,
FlexEnd = 3,
Center = 4,
Baseline = 5,
Stretch = 6,
}Expand description
The position-keyword half of AlignItems (and its aliases AlignSelf,
JustifyItems, JustifySelf).
Compute paths match on this enum directly so every match is exhaustive and
requires no Safe* siblings.
Variants
Start = 0
Items are packed toward the start of the axis.
End = 1
Items are packed toward the end of the axis.
FlexStart = 2
Items are packed towards the flex-relative start of the axis.
For flex containers with flex_direction RowReverse or ColumnReverse this is equivalent to End. In all other cases it is equivalent to Start.
FlexEnd = 3
Items are packed towards the flex-relative end of the axis.
For flex containers with flex_direction RowReverse or ColumnReverse this is equivalent to Start. In all other cases it is equivalent to End.
Center = 4
Items are packed along the center of the cross axis.
Baseline = 5
Items are aligned such as their baselines align.
Stretch = 6
Stretch to fill the container.