pub type AlignSelf = AlignItems;Expand description
Controls alignment of an individual node.
Overrides the parent Node’s AlignItems property.
For Flexbox it controls alignment in the cross axis.
For Grid it controls alignment in the block axis.
Aliased Type
pub struct AlignSelf {
pub keyword: AlignItemsKeyword,
pub safety: AlignmentSafety,
}Fields
keyword: AlignItemsKeywordPosition keyword.
safety: AlignmentSafetyOverflow-position modifier (safe / unsafe).