pub type JustifyItems = AlignItems;Expand description
Used to control how child nodes are aligned. Does not apply to Flexbox, and will be ignored if specified on a flex container. For Grid it controls alignment in the inline axis.
Aliased Type
pub struct JustifyItems {
pub keyword: AlignItemsKeyword,
pub safety: AlignmentSafety,
}Fields
keyword: AlignItemsKeywordPosition keyword.
safety: AlignmentSafetyOverflow-position modifier (safe / unsafe).